@@ -6,8 +6,6 @@ from .store_file_local import store_file_local
 from .TemporaryDirectory import TemporaryDirectory
 from ._safe_pickle import _safe_pickle, _safe_unpickle
 
-from .request_file_experimental import request_file_experimental
-    
 def store_text(text: str, *, label: Union[str, None]=None, cache_locally: bool=False, local: bool=False) -> str:
     with TemporaryDirectory() as tmpdir:
         fname = f'{tmpdir}/file.dat'
@@ -61,34 +59,6 @@ def load_pkl(uri: str, *, local_only: bool=False) -> Union[Any, None]:
         return None
     return _safe_unpickle(local_path)
 
-def request_text_experimental(uri: str, *, project_id: str) -> Union[str, None]:
-    local_path = request_file_experimental(uri, project_id=project_id)
-    if local_path is None:
-        return None
-    with open(local_path, 'r') as f:
-        return f.read()
-
-def request_json_experimental(uri: str, *, project_id: str) -> Union[dict, None]:
-    import simplejson
-    local_path = request_file_experimental(uri, project_id=project_id)
-    if local_path is None:
-        return None
-    with open(local_path, 'r') as f:
-        return simplejson.load(f)
-
-def request_npy_experimental(uri: str, *, project_id: str) -> Union[Any, None]:
-    import numpy as np
-    local_path = request_file_experimental(uri, project_id=project_id)
-    if local_path is None:
-        return None
-    return np.load(local_path, allow_pickle=False)
-
-def request_pkl_experimental(uri: str, *, project_id: str) -> Union[Any, None]:
-    local_path = request_file_experimental(uri, project_id=project_id)
-    if local_path is None:
-        return None
-    return _safe_unpickle(local_path)
-
 def store_text_local(text: str, label: Union[str, None]=None) -> str:
     with TemporaryDirectory() as tmpdir:
         fname = f'{tmpdir}/file.dat'
