@@ -31,7 +31,7 @@ def load_file(uri: str, *, verbose: bool=False, local_only: bool=False, dest: Un
             raise Exception('Unable to get jot')
         uri = uri2
     
-    if uri.startswith('github://'):
+    if uri.startswith('gh://'):
         return _load_github_file(uri)
 
     if local_only:
@@ -160,10 +160,12 @@ def _load_zenodo_file_from_cloud(uri: str, *, dest: Union[None, str]=None):
     return filename
 
 def _load_sha1_file_from_cloud(sha1: str, *, verbose: bool, dest: Union[None, str]=None, _get_info: bool=False) -> Union[str, dict, None]:
+    kachery_zone = os.environ.get('KACHERY_ZONE', 'default')
     payload = {
         'type': 'findFile',
         'hashAlg': 'sha1',
-        'hash': sha1
+        'hash': sha1,
+        'zone': kachery_zone
     }
     if os.environ.get('USE_KACHERY_GATEWAY', '') == '0':
         response= _kacherycloud_request(payload)
@@ -255,8 +257,12 @@ def load_file_local(uri: str, *, dest: Union[None, str]=None) -> Union[str, None
                 return location
     
     # check for linked file
-    a_txt = get_mutable_local(f'@linked_files/@sha1/{sha1}')
-    if a_txt is not None:
+    s = sha1
+    linked_file_record_parent_dir = f'{kachery_cloud_dir}/linked_files/sha1/{s[0]}{s[1]}/{s[2]}{s[3]}/{s[4]}{s[5]}'
+    linked_file_record_path = f'{linked_file_record_parent_dir}/{sha1}'
+    if os.path.exists(linked_file_record_path):
+        with open(linked_file_record_path, 'r') as f:
+            a_txt = f.read()
         a = json.loads(a_txt)
         path0 = a['path']
         size0 = a['size']
@@ -267,14 +273,15 @@ def load_file_local(uri: str, *, dest: Union[None, str]=None) -> Union[str, None
                     shutil.copyfile(path0, dest)
                     return dest
                 return path0
-            sha1_0 = _compute_file_hash(path0, algorithm='sha1')
-            if sha1_0 == sha1:
-                set_mutable_local(f'@linked_files/@sha1/{sha1}', json.dumps({
-                    'path': path0,
-                    'size': os.path.getsize(path0),
-                    'mtime': os.stat(path0).st_mtime,
-                    'sha1': sha1
-                }))
+            if (os.path.getsize(path0) == size0) and (_compute_file_hash(path0, algorithm='sha1') == sha1):
+                # file mtime has been updated, but hash is still the same
+                with open(linked_file_record_path, 'w') as f:
+                    f.write(json.dumps({
+                        'path': path0,
+                        'size': os.path.getsize(path0),
+                        'mtime': os.stat(path0).st_mtime,
+                        'sha1': sha1
+                    }))
                 if dest is not None:
                     shutil.copyfile(path0, dest)
                     return dest
